@@ -10,12 +10,11 @@ our @ISA = qw(Test);
 our @EXPORT=qw(makefile fileok plan ok);
 
 sub import {
-    my $pkg = shift;
     my $workdir = tempdir(CLEANUP => 1);
     chdir($workdir) or croak "can't change to $workdir: $!";
     @pattern = grep { /[\w\d]+/ } map { chr($_) } (1..127);
     delete $ENV{VERSION_CONTROL};
-    $pkg->export_to_level(1, @_);
+    $_[0]->export_to_level(1, @_);
 }    
 
 sub makefile {
